@@ -34,13 +34,9 @@ ${$msgs{'en'}}[0] = '©';
 # my %uses = ();
 
 my $num_list = Locale::PO->load_file_asarray("$srcdir/codes.po");
-my $curmsg = -1;
 foreach my $po_entry (@{$num_list}) {
     my $msgno = $po_entry->dequote($po_entry->msgstr);
     next if $msgno !~ /^\d+$/;
-    if ($msgno < $curmsg) {
-	print STDERR "Warning: message number jumps back from $curmsg to $msgno\n";
-    }
     my $key = $po_entry->msgid;
     my $msg = c_unescape($po_entry->dequote($key));
     if (${$msgs{'en'}}[$msgno]) {
@@ -188,6 +184,16 @@ sub sanity_check {
        print STDERR "Warning: $where is missing menu shortcut\n";
    }
 
+   # Check for missing (or added) double quotes (“ and ”)
+   if (scalar($msg =~ s/“/$&/g) != scalar($orig =~ s/“/$&/g)) {
+       print STDERR "Warning: $where has different numbers of “\n";
+       print STDERR "$orig\n$msg\n\n";
+   }
+   if (scalar($msg =~ s/”/$&/g) != scalar($orig =~ s/”/$&/g)) {
+       print STDERR "Warning: $where has different numbers of ”\n";
+       print STDERR "$orig\n$msg\n\n";
+   }
+
    # Check for missing (or added) menu accelerator "##"
    if ($msg =~ /\#\#/ && $orig !~ /\#\#/) {
        print STDERR "Warning: $where has menu accelerator but original doesn't\n";
