@@ -135,7 +135,16 @@ AboutDlg::AboutDlg(wxWindow* parent, const wxString & icon_path_) :
 	      0, wxLEFT | wxRIGHT, 20);
 
     info = wxGetOsDescription();
-    info += wxT("\n") wxVERSION_STRING
+#if wxCHECK_VERSION(2,9,2)
+    info += wxT("\n");
+    wxString version = wxGetLibraryVersionInfo().GetVersionString();
+    info += version;
+    if (version != wxVERSION_STRING)
+	info += wxT(" (built with ") wxVERSION_STRING wxT(")");
+    info +=
+#else
+    info += wxT("\nBuilt with ") wxVERSION_STRING
+#endif
 #ifdef __WXGTK__
 # if defined __WXGTK26__
 	wxT(" (GTK+ >= 2.6)\n");
