@@ -105,6 +105,8 @@ CavernLogWindow::OnLinkClicked(const wxHtmlLinkInfo &link)
     if (colon != wxString::npos) {
 #ifdef __WXMSW__
 	wxString cmd = wxT("notepad $f");
+#elif defined __WXMAC__
+	wxString cmd = wxT("open -t $f");
 #else
 	wxString cmd = wxT("x-terminal-emulator -title $t -e vim -c $l $f");
 	// wxString cmd = "x-terminal-emulator -title $t -e emacs +$l $f";
@@ -121,7 +123,7 @@ CavernLogWindow::OnLinkClicked(const wxHtmlLinkInfo &link)
 	size_t i = 0;
 	while ((i = cmd.find(wxT('$'), i)) != wxString::npos) {
 	    if (++i >= cmd.size()) break;
-	    switch (cmd[i]) {
+	    switch ((int)cmd[i]) {
 		case wxT('$'):
 		    cmd.erase(i, 1);
 		    break;
@@ -207,7 +209,7 @@ CavernLogWindow::process(const wxString &file)
 #endif
     if (!cavern_out) {
 	wxString m;
-	m.Printf(wmsg(/*Couldn't open pipe: `%s'*/17), cmd.c_str());
+	m.Printf(wmsg(/*Couldn’t open pipe: “%s”*/17), cmd.c_str());
 	m += wxT(" (");
 	m += wxString(strerror(errno), wxConvUTF8);
 	m += wxT(')');
