@@ -1,6 +1,6 @@
 /* datain.c
  * Reads in survey files, dealing with special characters, keywords & data
- * Copyright (C) 1991-2003,2005,2009,2010 Olly Betts
+ * Copyright (C) 1991-2003,2005,2009,2010,2011 Olly Betts
  * Copyright (C) 2004 Simeon Warner
  *
  * This program is free software; you can redistribute it and/or modify
@@ -349,7 +349,7 @@ data_file(const char *pth, const char *fnm)
       }
 
       if (fh == NULL) {
-	 compile_error(/*Couldn't open data file `%s'*/24, fnm);
+	 compile_error(/*Couldn’t open data file “%s”*/24, fnm);
 	 return;
       }
 
@@ -852,7 +852,7 @@ handle_compass(real *p_var)
 	 diff -= floor((diff + M_PI) / (2 * M_PI)) * 2 * M_PI;
 	 if (sqrd(diff / 2.0) > compvar + VAR(Q_BACKBEARING)) {
 	    /* fore and back readings differ by more than 2 sds */
-	    warn_readings_differ(/*Compass reading and back compass reading disagree by %s degrees*/98, diff);
+	    warn_readings_differ(/*COMPASS reading and BACKCOMPASS reading disagree by %s degrees*/98, diff);
 	 }
 	 comp = (comp / compvar + backcomp / VAR(BackComp));
 	 compvar = (compvar + VAR(BackComp)) / 4;
@@ -927,7 +927,7 @@ process_normal(prefix *fr, prefix *to, bool fToFirst,
    }
 
    if (ctype != CTYPE_OMIT && backctype != CTYPE_OMIT && ctype != backctype) {
-      compile_error_skip(/*Clino and BackClino readings must be of the same type*/84);
+      compile_error_skip(/*CLINO and BACKCLINO readings must be of the same type*/84);
       return 0;
    }
 
@@ -948,7 +948,7 @@ process_normal(prefix *fr, prefix *to, bool fToFirst,
       if (ctype != CTYPE_OMIT) {
 	 if (backctype != CTYPE_OMIT && (clin > 0) == (backclin > 0)) {
 	    /* We've got two UPs or two DOWNs - FIXME: not ideal message */
-	    compile_error_skip(/*Clino and BackClino readings must be of the same type*/84);
+	    compile_error_skip(/*CLINO and BACKCLINO readings must be of the same type*/84);
 	    return 0;
 	 }
 	 dz = (clin > (real)0.0) ? tape : -tape;
@@ -996,7 +996,7 @@ process_normal(prefix *fr, prefix *to, bool fToFirst,
 	    if (ctype == CTYPE_READING) {
 	       if (sqrd((clin + backclin) / 3.0) > var_clin + VAR(BackClino)) {
 		  /* fore and back readings differ by more than 3 sds */
-		  warn_readings_differ(/*Clino reading and back clino reading disagree by %s degrees*/99, clin + backclin);
+		  warn_readings_differ(/*CLINO reading and BACKCLINO reading disagree by %s degrees*/99, clin + backclin);
 	       }
 	       clin = (clin / var_clin - backclin / VAR(BackClino));
 	       var_clin = (var_clin + VAR(BackClino)) / 4;
@@ -1401,7 +1401,7 @@ data_normal(void)
 	     fRev = fTrue;
 	     break;
 	   default:
-	     compile_error_skip(/*Found `%s', expecting `F' or `B'*/131,
+	     compile_error_skip(/*Found “%s”, expecting “F” or “B”*/131,
 				buffer);
 	     process_eol();
 	     return 0;
@@ -1433,7 +1433,7 @@ data_normal(void)
 	  if (VAL(Clino) == HUGE_REAL) {
 	     VAL(Clino) = handle_plumb(&ctype);
 	     if (VAL(Clino) != HUGE_REAL) break;
-	     compile_error_token(/*Expecting numeric field, found `%s'*/9);
+	     compile_error_token(/*Expecting numeric field, found “%s”*/9);
 	     process_eol();
 	     return 0;
 	  }
@@ -1444,7 +1444,7 @@ data_normal(void)
 	  if (VAL(BackClino) == HUGE_REAL) {
 	     VAL(BackClino) = handle_plumb(&backctype);
 	     if (VAL(BackClino) != HUGE_REAL) break;
-	     compile_error_token(/*Expecting numeric field, found `%s'*/9);
+	     compile_error_token(/*Expecting numeric field, found “%s”*/9);
 	     process_eol();
 	     return 0;
 	  }
@@ -1705,7 +1705,7 @@ data_passage(void)
 	 read_reading(*ordering, fTrue);
          if (VAL(*ordering) == HUGE_REAL) {
             if (!isOmit(ch)) {
-               compile_error_token(/*Expecting numeric field, found `%s'*/9);
+	       compile_error_token(/*Expecting numeric field, found “%s”*/9);
             }
 	    nextch();
             VAL(*ordering) = -1;
