@@ -69,11 +69,19 @@ sub replacement {
     if (exists $revmsgs{$msg}) {
 	$msgno = $revmsgs{$msg};
     } else {
-	if (!$die) {
-	    print STDERR "Message(s) not found in message file:\n";
-	    $die = 1;
+	my $tmp = $msg;
+	$tmp =~ s/`(.*?)'/“$1”/g;
+	$tmp =~ s/(\w)'(\w)/$1’$2/g;
+	if (exists $revmsgs{$tmp}) {
+	    $msg = $tmp;
+	    $msgno = $revmsgs{$msg};
+	} else {
+	    if (!$die) {
+		print STDERR "Message(s) not found in message file:\n";
+		$die = 1;
+	    }
+	    print STDERR "'$msg'\n";
 	}
-	print STDERR "'$msg'\n";
     }
     return "msg(/*$msg*/$msgno)";
 }
