@@ -4,7 +4,7 @@
 //  Core drawing code for Aven.
 //
 //  Copyright (C) 2000-2003,2005,2006 Mark R. Shinwell
-//  Copyright (C) 2001-2003,2004,2005,2006,2007,2010,2011 Olly Betts
+//  Copyright (C) 2001-2003,2004,2005,2006,2007,2010,2011,2012 Olly Betts
 //  Copyright (C) 2005 Martin Green
 //
 //  This program is free software; you can redistribute it and/or modify
@@ -211,6 +211,19 @@ void GfxCore::Initialise(bool same_file)
 
     m_HaveData = true;
 
+    // Clear any cached OpenGL lists which depend on the data.
+    InvalidateList(LIST_SCALE_BAR);
+    InvalidateList(LIST_DEPTH_KEY);
+    InvalidateList(LIST_DATE_KEY);
+    InvalidateList(LIST_ERROR_KEY);
+    InvalidateList(LIST_UNDERGROUND_LEGS);
+    InvalidateList(LIST_TUBES);
+    InvalidateList(LIST_SURFACE_LEGS);
+    InvalidateList(LIST_BLOBS);
+    InvalidateList(LIST_CROSSES);
+    InvalidateList(LIST_GRID);
+    InvalidateList(LIST_SHADOW);
+
     ForceRefresh();
 }
 
@@ -229,8 +242,6 @@ void GfxCore::FirstShow()
 	label->set_width(unsigned(ext_x) / quantise + 1);
     }
 
-    SetBackgroundColour(0.0, 0.0, 0.0);
-
     // Set diameter of the viewing volume.
     SetVolumeDiameter(sqrt(sqrd(m_Parent->GetXExtent()) +
 			   sqrd(m_Parent->GetYExtent()) +
@@ -303,8 +314,6 @@ void GfxCore::OnPaint(wxPaintEvent&)
     // Get a graphics context.
     wxPaintDC dc(this);
 
-    assert(GetContext());
-
     if (m_HaveData) {
 	// Make sure we're initialised.
 	bool first_time = !m_DoneFirstShow;
@@ -367,6 +376,16 @@ void GfxCore::OnPaint(wxPaintEvent&)
 	    }
 	}
 
+	// Draw indicators.
+	//
+	// There's no advantage in generating an OpenGL list for the
+	// indicators since they change with almost every redraw (and
+	// sometimes several times between redraws).  This way we avoid
+	// the need to track when to update the indicator OpenGL list,
+	// and also avoid indicator update bugs when we don't quite get this
+	// right...
+	DrawIndicators();
+
 	if (MeasuringLineActive()) {
 	    // Draw "here" and "there".
 	    double hx, hy;
@@ -392,16 +411,6 @@ void GfxCore::OnPaint(wxPaintEvent&)
 	    }
 	}
 
-	// Draw indicators.
-	//
-	// There's no advantage in generating an OpenGL list for the
-	// indicators since they change with almost every redraw (and
-	// sometimes several times between redraws).  This way we avoid
-	// the need to track when to update the indicator OpenGL list,
-	// and also avoid indicator update bugs when we don't quite get this
-	// right...
-	DrawIndicators();
-
 	FinishDrawing();
 
 	drawtime = timer.Time();
@@ -772,11 +781,12 @@ void GfxCore::SimpleDrawNames()
     }
 }
 
-void GfxCore::DrawColourKey(int num_bands, const wxString & other)
+void GfxCore::DrawColourKey(int num_bands, const wxString & other, const wxString & units)
 {
     int total_block_height =
 	KEY_BLOCK_HEIGHT * (num_bands == 1 ? num_bands : num_bands - 1);
     if (!other.empty()) total_block_height += KEY_BLOCK_HEIGHT * 2;
+    if (!units.empty()) total_block_height += KEY_BLOCK_HEIGHT;
 
     const int bottom = -total_block_height;
 
@@ -795,6 +805,7 @@ void GfxCore::DrawColourKey(int num_bands, const wxString & other)
     key_lowerleft[m_ColourBy].y = bottom;
 
     int y = bottom;
+    if (!units.empty()) y += KEY_BLOCK_HEIGHT;
 
     if (!other.empty()) {
 	DrawShadedRectangle(GetSurfacePen(), GetSurfacePen(), left, y,
@@ -832,10 +843,17 @@ void GfxCore::DrawColourKey(int num_bands, const wxString & other)
     PlaceIndicatorVertex(left, y);
     EndPolyline();
 
-    y = bottom - GetFontSize() / 2;
+    SetColour(TEXT_COLOUR);
+
+    y = bottom;
+    if (!units.empty()) {
+	GetTextExtent(units, &size, NULL);
+	DrawIndicatorText(left + (KEY_BLOCK_WIDTH - size) / 2, y, units);
+	y += KEY_BLOCK_HEIGHT;
+    }
+    y -= GetFontSize() / 2;
     left += KEY_BLOCK_WIDTH + 5;
 
-    SetColour(TEXT_COLOUR);
     if (!other.empty()) {
 	y += KEY_BLOCK_HEIGHT / 2;
 	DrawIndicatorText(left, y, other);
@@ -856,21 +874,28 @@ void GfxCore::DrawColourKey(int num_bands, const wxString & other)
 void GfxCore::DrawDepthKey()
 {
     Double z_ext = m_Parent->GetDepthExtent();
-    int num_bands;
-    if (z_ext == 0) {
-	num_bands = 1;
-    } else {
+    int num_bands = 1;
+    int sf = 0;
+    if (z_ext > 0.0) {
 	num_bands = GetNumColourBands();
+	Double z_range = z_ext;
+	if (!m_Metric) z_range /= METRES_PER_FOOT;
+	sf = max(0, 1 - (int)floor(log10(z_range)));
     }
 
-    for (int band = 0; band < GetNumColourBands(); ++band) {
-	Double z = m_Parent->GetDepthMin() + m_Parent->GetOffset().GetZ();
+    Double z_min = m_Parent->GetDepthMin() + m_Parent->GetOffset().GetZ();
+    for (int band = 0; band < num_bands; ++band) {
+	Double z = z_min;
 	if (band)
 	    z += z_ext * band / (num_bands - 1);
-	key_legends[band] = FormatLength(z, false);
+
+	if (!m_Metric)
+	    z /= METRES_PER_FOOT;
+
+	key_legends[band].Printf(wxT("%.*f"), sf, z);
     }
 
-    DrawColourKey(num_bands, wxString());
+    DrawColourKey(num_bands, wxString(), m_Metric ? wxT("m") : wxT("ft"));
 }
 
 void GfxCore::DrawDateKey()
@@ -900,7 +925,7 @@ void GfxCore::DrawDateKey()
 	other = wmsg(/*Undated*/221);
     }
 
-    DrawColourKey(num_bands, other);
+    DrawColourKey(num_bands, other, wxString());
 }
 
 void GfxCore::DrawErrorKey()
@@ -919,71 +944,7 @@ void GfxCore::DrawErrorKey()
     }
 
     // Always show the "Not in loop" legend for now (FIXME).
-    DrawColourKey(num_bands, wmsg(/*Not in loop*/290));
-}
-
-wxString GfxCore::FormatLength(Double size_snap, bool scalebar)
-{
-    wxString str;
-    bool negative = (size_snap < 0.0);
-
-    if (negative) {
-	size_snap = -size_snap;
-    }
-
-    if (size_snap == 0.0) {
-	str = wxT("0");
-    } else if (m_Metric) {
-#ifdef SILLY_UNITS
-	if (size_snap < 1e-12) {
-	    str.Printf(wxT("%.3gpm"), size_snap * 1e12);
-	} else if (size_snap < 1e-9) {
-	    str.Printf(wxT("%.fpm"), size_snap * 1e12);
-	} else if (size_snap < 1e-6) {
-	    str.Printf(wxT("%.fnm"), size_snap * 1e9);
-	} else if (size_snap < 1e-3) {
-	    str.Printf(wxT("%.fum"), size_snap * 1e6);
-#else
-	if (size_snap < 1e-3) {
-	    str.Printf(wxT("%.3gmm"), size_snap * 1e3);
-#endif
-	} else if (size_snap < 1e-2) {
-	    str.Printf(wxT("%.fmm"), size_snap * 1e3);
-	} else if (size_snap < 1.0) {
-	    str.Printf(wxT("%.fcm"), size_snap * 100.0);
-	} else if (size_snap < 1e3) {
-	    str.Printf(wxT("%.fm"), size_snap);
-#ifdef SILLY_UNITS
-	} else if (size_snap < 1e6) {
-	    str.Printf(wxT("%.fkm"), size_snap * 1e-3);
-	} else if (size_snap < 1e9) {
-	    str.Printf(wxT("%.fMm"), size_snap * 1e-6);
-	} else {
-	    str.Printf(wxT("%.fGm"), size_snap * 1e-9);
-#else
-	} else {
-	    str.Printf(scalebar ? wxT("%.fkm") : wxT("%.2fkm"), size_snap * 1e-3);
-#endif
-	}
-    } else {
-	size_snap /= METRES_PER_FOOT;
-	if (scalebar) {
-	    Double inches = size_snap * 12;
-	    if (inches < 1.0) {
-		str.Printf(wxT("%.3gin"), inches);
-	    } else if (size_snap < 1.0) {
-		str.Printf(wxT("%.fin"), inches);
-	    } else if (size_snap < 5279.5) {
-		str.Printf(wxT("%.fft"), size_snap);
-	    } else {
-		str.Printf(wxT("%.f miles"), size_snap / 5280.0);
-	    }
-	} else {
-	    str.Printf(wxT("%.fft"), size_snap);
-	}
-    }
-
-    return negative ? wxString(wxT("-")) + str : str;
+    DrawColourKey(num_bands, wmsg(/*Not in loop*/290), wxString());
 }
 
 void GfxCore::DrawScaleBar()
@@ -1045,7 +1006,35 @@ void GfxCore::DrawScaleBar()
     }
 
     // Add labels.
-    wxString str = FormatLength(size_snap);
+    wxString str;
+    if (m_Metric) {
+	if (size_snap >= 1e3) {
+	    str.Printf(wxT("%.fkm"), size_snap * 1e-3);
+	} else if (size_snap >= 1.0) {
+	    str.Printf(wxT("%.fm"), size_snap);
+	} else {
+	    int sf = -(int)floor(log10(size_snap));
+	    str.Printf(wxT("%.*fm"), sf, size_snap);
+	}
+    } else {
+	size_snap /= METRES_PER_FOOT;
+	Double miles = size_snap / 5280.0;
+	if (miles >= 2.0) {
+	    str.Printf(wxT("%.f miles"), miles);
+	} else if (miles >= 1.0) {
+	    str.Printf(wxT("%.f mile"), miles);
+	} else if (size_snap >= 1.0) {
+	    str.Printf(wxT("%.fft"), size_snap);
+	} else {
+	    Double inches = size_snap * 12;
+	    if (inches >= 1.0) {
+		str.Printf(wxT("%.fin"), inches);
+	    } else {
+		int sf = -(int)floor(log10(inches));
+		str.Printf(wxT("%.*fin"), sf, inches);
+	    }
+	}
+    }
 
     int text_width, text_height;
     GetTextExtent(str, &text_width, &text_height);
@@ -2978,7 +2967,7 @@ bool GfxCore::HandleRClick(wxPoint point)
 	menu.AppendSeparator();
 	menu.AppendCheckItem(menu_IND_COMPASS, wmsg(/*&Hide Compass*/387));
 	menu.AppendCheckItem(menu_CTL_DEGREES, wmsg(/*&Degrees*/343));
-	menu.Connect(wxEVT_COMMAND_MENU_SELECTED, (wxObjectEventFunction)&MainFrm::ProcessEvent, NULL, m_Parent);
+	menu.Connect(wxEVT_COMMAND_MENU_SELECTED, (wxObjectEventFunction)&wxEvtHandler::ProcessEvent, NULL, m_Parent->GetEventHandler());
 	PopupMenu(&menu);
 	return true;
     }
@@ -2991,7 +2980,7 @@ bool GfxCore::HandleRClick(wxPoint point)
 	menu.AppendSeparator();
 	menu.AppendCheckItem(menu_IND_CLINO, wmsg(/*&Hide Clino*/384));
 	menu.AppendCheckItem(menu_CTL_DEGREES, wmsg(/*&Degrees*/343));
-	menu.Connect(wxEVT_COMMAND_MENU_SELECTED, (wxObjectEventFunction)&MainFrm::ProcessEvent, NULL, m_Parent);
+	menu.Connect(wxEVT_COMMAND_MENU_SELECTED, (wxObjectEventFunction)&wxEvtHandler::ProcessEvent, NULL, m_Parent->GetEventHandler());
 	PopupMenu(&menu);
 	return true;
     }
@@ -3001,7 +2990,7 @@ bool GfxCore::HandleRClick(wxPoint point)
 	wxMenu menu;
 	menu.AppendCheckItem(menu_IND_SCALE_BAR, wmsg(/*&Hide scale bar*/385));
 	menu.AppendCheckItem(menu_CTL_METRIC, wmsg(/*&Metric*/342));
-	menu.Connect(wxEVT_COMMAND_MENU_SELECTED, (wxObjectEventFunction)&MainFrm::ProcessEvent, NULL, m_Parent);
+	menu.Connect(wxEVT_COMMAND_MENU_SELECTED, (wxObjectEventFunction)&wxEvtHandler::ProcessEvent, NULL, m_Parent->GetEventHandler());
 	PopupMenu(&menu);
 	return true;
     }
@@ -3016,7 +3005,7 @@ bool GfxCore::HandleRClick(wxPoint point)
 	menu.AppendCheckItem(menu_IND_COLOUR_KEY, wmsg(/*&Hide colour key*/386));
 	if (m_ColourBy == COLOUR_BY_DEPTH)
 	    menu.AppendCheckItem(menu_CTL_METRIC, wmsg(/*&Metric*/342));
-	menu.Connect(wxEVT_COMMAND_MENU_SELECTED, (wxObjectEventFunction)&MainFrm::ProcessEvent, NULL, m_Parent);
+	menu.Connect(wxEVT_COMMAND_MENU_SELECTED, (wxObjectEventFunction)&wxEvtHandler::ProcessEvent, NULL, m_Parent->GetEventHandler());
 	PopupMenu(&menu);
 	return true;
     }
