@@ -4,7 +4,7 @@
 //  OpenGL implementation for the GLA abstraction layer.
 //
 //  Copyright (C) 2002-2003,2005 Mark R. Shinwell
-//  Copyright (C) 2003,2004,2005,2006,2007,2010,2011 Olly Betts
+//  Copyright (C) 2003,2004,2005,2006,2007,2010,2011,2012 Olly Betts
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -138,12 +138,16 @@ string GetGLSystemDescription()
 //            (thus it must not be called from BeginLines(), etc., or within a
 //             BeginLines()/EndLines() block etc.)
 #define CHECK_GL_ERROR(M, F) do { \
+    if (!opengl_initialised) { \
+	wxLogError(wxT(__FILE__":"STRING(__LINE__)": OpenGL not initialised before (call "F" in method "M")")); \
+    } \
     GLenum error_code_ = glGetError(); \
-    if (error_code_ != GL_NO_ERROR) \
+    if (error_code_ != GL_NO_ERROR) { \
 	wxLogError(wxT(__FILE__":"STRING(__LINE__)": OpenGL error: %s " \
 		   "(call "F" in method "M")"), \
 		   wxString((const char *)gluErrorString(error_code_), \
 			    wxConvUTF8).c_str()); \
+    } \
 } while (0)
 
 //
@@ -206,17 +210,61 @@ const ColourTriple COLOURS[] = {
     { 40, 40, 255 },   // blue
 };
 
-void GLAList::DrawList() const {
-    glCallList(gl_list);
-    CHECK_GL_ERROR("GLAList::DrawList", "glCallList");
+bool GLAList::need_to_generate() {
+    // Bail out if the list is already cached, or can't usefully be cached.
+    if (flags & (GLACanvas::CACHED|GLACanvas::NEVER_CACHE))
+	return false;
+
+    // Create a new OpenGL list to hold this sequence of drawing
+    // operations.
+    if (gl_list == 0) {
+	gl_list = glGenLists(1);
+	CHECK_GL_ERROR("GLAList::need_to_generate", "glGenLists");
+#ifdef GLA_DEBUG
+	printf("glGenLists(1) returned %u\n", (unsigned)gl_list);
+#endif
+	if (gl_list == 0) {
+	    // If we can't create a list for any reason, fall back to just
+	    // drawing directly, and flag the list as NEVER_CACHE as there's
+	    // unlikely to be much point calling glGenLists() again.
+	    flags = GLACanvas::NEVER_CACHE;
+	    return false;
+	}
+
+	// We should have 256 lists for font drawing and a dozen or so for 2D
+	// and 3D lists.  So something is amiss if we've generated 1000 lists,
+	// probably a infinite loop in the lazy list mechanism.
+	assert(gl_list < 1000);
+    }
+    // http://www.opengl.org/resources/faq/technical/displaylist.htm advises:
+    //
+    // "Stay away from GL_COMPILE_AND_EXECUTE mode. Instead, create the
+    // list using GL_COMPILE mode, then execute it with glCallList()."
+    glNewList(gl_list, GL_COMPILE);
+    CHECK_GL_ERROR("GLAList::need_to_generate", "glNewList");
+    return true;
 }
 
-void GLAList::InvalidateList() {
-    glDeleteLists(gl_list, 1);
-    CHECK_GL_ERROR("GLAList::InvalidateList", "glDeleteLists");
+void GLAList::finalise(unsigned int list_flags)
+{
+    glEndList();
+    CHECK_GL_ERROR("GLAList::finalise", "glEndList");
+    if (list_flags & GLACanvas::NEVER_CACHE) {
+	glDeleteLists(gl_list, 1);
+	CHECK_GL_ERROR("GLAList::finalise", "glDeleteLists");
+	gl_list = 0;
+	flags = GLACanvas::NEVER_CACHE;
+    } else {
+	flags = list_flags | GLACanvas::CACHED;
+    }
+}
 
-    // And flag this list as requiring generation before use.
-    gl_list = 0;
+bool GLAList::DrawList() const {
+    if ((flags & GLACanvas::CACHED) == 0)
+	return false;
+    glCallList(gl_list);
+    CHECK_GL_ERROR("GLAList::DrawList", "glCallList");
+    return true;
 }
 
 //
@@ -259,9 +307,20 @@ void GLACanvas::FirstShow()
 {
     // Update our record of the client area size and centre.
     GetClientSize(&x_size, &y_size);
+    if (x_size < 1) x_size = 1;
+    if (y_size < 1) y_size = 1;
 
     SetCurrent();
     opengl_initialised = true;
+
+    // Set the background colour of the canvas to black.
+    glClearColor(0.0, 0.0, 0.0, 1.0);
+    CHECK_GL_ERROR("FirstShow", "glClearColor");
+
+    // Set viewport.
+    glViewport(0, 0, x_size, y_size);
+    CHECK_GL_ERROR("FirstShow", "glViewport");
+
     save_hints = false;
     vendor = wxString((const char *)glGetString(GL_VENDOR), wxConvUTF8);
     renderer = wxString((const char *)glGetString(GL_RENDERER), wxConvUTF8);
@@ -286,13 +345,6 @@ void GLACanvas::FirstShow()
 	}
     }
 
-    // Clear any cached OpenGL lists.
-    vector<GLAList>::iterator i;
-    for (i = drawing_lists.begin(); i != drawing_lists.end(); ++i) {
-	if (*i) i->InvalidateList();
-    }
-    drawing_lists.resize(0);
-
     if (m_Quadric) return;
     // One time initialisation follows.
 
@@ -309,6 +361,13 @@ void GLACanvas::FirstShow()
     //glAlphaFunc(GL_GREATER, 0.5f);
     //CHECK_GL_ERROR("FirstShow", "glAlphaFunc");
 
+    // We want glReadPixels() to read from the front buffer (which is the
+    // default for single-buffered displays).
+    if (double_buffered) {
+	glReadBuffer(GL_FRONT);
+	CHECK_GL_ERROR("FirstShow", "glReadBuffer");
+    }
+
     // Grey fog effect.
     GLfloat fogcolour[4] = { 0.5, 0.5, 0.5, 1.0 };
     glFogfv(GL_FOG_COLOR, fogcolour);
@@ -446,7 +505,7 @@ void GLACanvas::SetScale(Double scale)
     if (scale != m_Scale) {
 	vector<GLAList>::iterator i;
 	for (i = drawing_lists.begin(); i != drawing_lists.end(); ++i) {
-	    if (*i && i->test_flag(INVALIDATE_ON_SCALE)) i->InvalidateList();
+	    i->invalidate_if(INVALIDATE_ON_SCALE);
 	}
 
 	m_Scale = scale;
@@ -463,15 +522,25 @@ void GLACanvas::OnSize(wxSizeEvent & event)
     if (mask) {
 	vector<GLAList>::iterator i;
 	for (i = drawing_lists.begin(); i != drawing_lists.end(); ++i) {
-	    if (*i && i->test_flag(mask)) i->InvalidateList();
+	    i->invalidate_if(mask);
 	}
 
+	// The width and height go to zero when the panel is dragged right
+	// across so we clamp them to be at least 1 to avoid problems.
 	x_size = size.GetWidth();
 	y_size = size.GetHeight();
+	if (x_size < 1) x_size = 1;
+	if (y_size < 1) y_size = 1;
     }
 
     // This apparently is (or at least was) needed for Mac OS X.
     wxGLCanvas::OnSize(event);
+
+    if (!opengl_initialised) return;
+
+    // Set viewport.
+    glViewport(0, 0, x_size, y_size);
+    CHECK_GL_ERROR("OnSize", "glViewport");
 }
 
 void GLACanvas::AddTranslationScreenCoordinates(int dx, int dy)
@@ -526,13 +595,15 @@ void GLACanvas::StartDrawing()
 #define o 0,0,0
 #define I 255,255,255
 	    o, o, o, o, o, o, o, o,
-	    o, I, o, o, o, o, I, o,
-	    o, o, I, o, o, I, o, o,
-	    o, o, o, I, I, o, o, o,
-	    o, o, o, I, I, o, o, o,
-	    o, o, I, o, o, I, o, o,
-	    o, I, o, o, o, o, I, o,
-	    o, o, o, o, o, o, o, o
+	    I, o, o, o, o, o, I, o,
+	    o, I, o, o, o, I, o, o,
+	    o, o, I, o, I, o, o, o,
+	    o, o, o, I, o, o, o, o,
+	    o, o, I, o, I, o, o, o,
+	    o, I, o, o, o, I, o, o,
+	    I, o, o, o, o, o, I, o
+#undef o
+#undef I
 	};
 	if (!CheckVisualFidelity(expected_cross)) {
 	    cross_method = LINES;
@@ -558,6 +629,8 @@ void GLACanvas::StartDrawing()
 	    o, I, I, I, I, I, o, o,
 	    o, o, I, I, I, o, o, o,
 	    o, o, o, o, o, o, o, o
+#undef o
+#undef I
 	};
 	if (!CheckVisualFidelity(expected_blob)) {
 	    blob_method = LINES;
@@ -622,25 +695,14 @@ void GLACanvas::PlaceNormal(const Vector3 &v)
 
 void GLACanvas::SetDataTransform()
 {
-    // Set viewport.  The width and height go to zero when the panel is dragged
-    // right across so we clamp them to be at least 1 to avoid errors from the
-    // opengl calls below.
-    int window_width;
-    int window_height;
-    GetSize(&window_width, &window_height);
-    if (window_height < 1) window_height = 1;
-    if (window_width < 1) window_width = 1;
-    double aspect = double(window_height) / double(window_width);
-
-    glViewport(0, 0, window_width, window_height);
-    CHECK_GL_ERROR("SetDataTransform", "glViewport");
-
     // Set projection.
     glMatrixMode(GL_PROJECTION);
     CHECK_GL_ERROR("SetDataTransform", "glMatrixMode");
     glLoadIdentity();
     CHECK_GL_ERROR("SetDataTransform", "glLoadIdentity");
 
+    double aspect = double(y_size) / double(x_size);
+
     Double near_plane = 1.0;
     if (m_Perspective) {
 	Double lr = near_plane * tan(rad(25.0));
@@ -752,9 +814,6 @@ void GLACanvas::SetIndicatorTransform()
     list_flags |= NEVER_CACHE;
 
     // Set the modelview transform and projection for drawing indicators.
-    wxSize size = GetSize();
-    int window_width = max(size.GetWidth(), 1);
-    int window_height = max(size.GetHeight(), 1);
 
     glDisable(GL_DEPTH_TEST);
     CHECK_GL_ERROR("SetIndicatorTransform", "glDisable GL_DEPTH_TEST");
@@ -766,7 +825,7 @@ void GLACanvas::SetIndicatorTransform()
     CHECK_GL_ERROR("SetIndicatorTransform", "glMatrixMode");
     glLoadIdentity();
     CHECK_GL_ERROR("SetIndicatorTransform", "glLoadIdentity (2)");
-    gluOrtho2D(0, window_width, 0, window_height);
+    gluOrtho2D(0, x_size, 0, y_size);
     CHECK_GL_ERROR("SetIndicatorTransform", "gluOrtho2D");
 
     // No modelview transform.
@@ -813,50 +872,26 @@ void GLACanvas::DrawList(unsigned int l)
 
     // We generate the OpenGL lists lazily to minimise delays on startup.
     // So check if we need to generate the OpenGL list now.
-    if (!drawing_lists[l] && !drawing_lists[l].test_flag(NEVER_CACHE)) {
-	// Create a new OpenGL list to hold this sequence of drawing
-	// operations.
-	GLuint list = glGenLists(1);
-#ifdef GLA_DEBUG
-	printf("new list #%d: %d... ", l, list);
-	m_Vertices = 0;
-#endif
-	CHECK_GL_ERROR("DrawList", "glGenLists");
-	if (list == 0) {
-	    // If we can't create a list, fall back to just drawing directly.
-	    GenerateList(l);
-	    return;
-	}
-
-	// We should have 256 lists for font drawing and a dozen or so for 2D
-	// and 3D lists.  So something is amiss if we've generated 1000 lists,
-	// probably a infinite loop in the lazy list mechanism.
-	assert(list < 1000);
-
-	// http://www.opengl.org/resources/faq/technical/displaylist.htm
-	// advises:
-	// "Stay away from GL_COMPILE_AND_EXECUTE mode. Instead, create the
-	// list using GL_COMPILE mode, then execute it with glCallList()."
-	glNewList(list, GL_COMPILE);
-	CHECK_GL_ERROR("DrawList", "glNewList");
+    if (drawing_lists[l].need_to_generate()) {
 	// Clear list_flags so that we can note what conditions to invalidate
 	// the cached OpenGL list on.
 	list_flags = 0;
+
+#ifdef GLA_DEBUG
+	printf("generating list #%u... ", l);
+	m_Vertices = 0;
+#endif
 	GenerateList(l);
-	glEndList();
-	CHECK_GL_ERROR("DrawList", "glEndList");
 #ifdef GLA_DEBUG
 	printf("done (%d vertices)\n", m_Vertices);
 #endif
-	drawing_lists[l] = GLAList(list, list_flags);
+	drawing_lists[l].finalise(list_flags);
     }
 
-    if (drawing_lists[l].test_flag(NEVER_CACHE)) {
-	// That list can't be cached.
+    if (!drawing_lists[l].DrawList()) {
+	// That list isn't cached (which means it probably can't usefully be
+	// cached).
 	GenerateList(l);
-    } else {
-	// Perform the operations specified by the OpenGL display list.
-	drawing_lists[l].DrawList();
     }
 }
 
@@ -879,22 +914,6 @@ void GLACanvas::DrawList2D(unsigned int l, glaCoord x, glaCoord y, Double rotati
     CHECK_GL_ERROR("DrawList2D", "glPopMatrix");
 }
 
-void GLACanvas::InvalidateList(unsigned int l)
-{
-    if (l < drawing_lists.size() && drawing_lists[l]) {
-	// Delete any existing OpenGL list.
-	drawing_lists[l].InvalidateList();
-    }
-}
-
-void GLACanvas::SetBackgroundColour(float red, float green, float blue)
-{
-    // Set the background colour of the canvas.
-
-    glClearColor(red, green, blue, 1.0);
-    CHECK_GL_ERROR("SetBackgroundColour", "glClearColor");
-}
-
 void GLACanvas::SetColour(const GLAPen& pen, double rgb_scale)
 {
     // Set the colour for subsequent operations.
@@ -1442,12 +1461,12 @@ void GLACanvas::ToggleTextured()
 
 bool GLACanvas::SaveScreenshot(const wxString & fnm, int type) const
 {
-    int width;
-    int height;
-    GetSize(&width, &height);
+    const int width = x_size;
+    const int height = y_size;
     unsigned char *pixels = (unsigned char *)malloc(3 * width * (height + 1));
     if (!pixels) return false;
     glReadPixels(0, 0, width, height, GL_RGB, GL_UNSIGNED_BYTE, (GLvoid *)pixels);
+    CHECK_GL_ERROR("SaveScreenshot", "glReadPixels");
     unsigned char * tmp_row = pixels + 3 * width * height;
     // We need to flip the image vertically - this approach should be more
     // efficient than using wxImage::Mirror(false) as that creates a new
@@ -1466,16 +1485,39 @@ bool GLACanvas::SaveScreenshot(const wxString & fnm, int type) const
 
 bool GLACanvas::CheckVisualFidelity(const unsigned char * target) const
 {
-    int width;
-    int height;
-    GetSize(&width, &height);
     unsigned char pixels[3 * 8 * 8];
-    glReadPixels(width / 2 - 3, height / 2 - 4, 8, 8, GL_RGB, GL_UNSIGNED_BYTE, (GLvoid *)pixels);
+    if (double_buffered) {
+	glReadBuffer(GL_BACK);
+	CHECK_GL_ERROR("FirstShow", "glReadBuffer");
+    }
+    glReadPixels(x_size / 2 - 3, y_size / 2 - 4, 8, 8,
+		 GL_RGB, GL_UNSIGNED_BYTE, (GLvoid *)pixels);
+    CHECK_GL_ERROR("CheckVisualFidelity", "glReadPixels");
+    if (double_buffered) {
+	glReadBuffer(GL_FRONT);
+	CHECK_GL_ERROR("FirstShow", "glReadBuffer");
+    }
+#if 0
+    // Show what got drawn and what was expected for debugging.
+    for (int y = 0; y < 8; ++y) {
+	for (int x = 0; x < 8; ++x) {
+	    int o = (y * 8 + x) * 3;
+	    printf("%c", pixels[o] ? 'X' : '.');
+	}
+	printf(" ");
+	for (int x = 0; x < 8; ++x) {
+	    int o = (y * 8 + x) * 3;
+	    printf("%c", target[o] ? 'X' : '.');
+	}
+	printf("\n");
+    }
+#endif
     return (memcmp(pixels, target, sizeof(pixels)) == 0);
 }
 
 void GLACanvas::ReadPixels(int width, int height, unsigned char * buf) const
 {
+    CHECK_GL_ERROR("ReadPixels", "glReadPixels");
     glReadPixels(0, 0, width, height, GL_RGB, GL_UNSIGNED_BYTE, (GLvoid *)buf);
 }
 
