@@ -1,7 +1,7 @@
 /* hpgl.cc
  * Export from Aven as HPGL.
  */
-/* Copyright (C) 1993-2003,2005 Olly Betts
+/* Copyright (C) 1993-2003,2005,2010 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -72,23 +72,23 @@ void HPGL::header(const char *)
 	 "SI0.125,.179;"
 #endif
 	 , fh);
-   if (fNewLines) putc('\n', fh);
+   if (fNewLines) PUTC('\n', fh);
 
 #ifndef HPGL_USE_UC
    /* define degree and copyright symbols */
    fputs("DL32,10,30,12,30,13,29,13,27,12,26,10,26,9,27,9,29,"
 	 "10,30;DL40,0,0;", fh); /* Hope this works! Seems to for BP */
-   if (fNewLines) putc('\n', fh);
+   if (fNewLines) PUTC('\n', fh);
 
    fputs("DL67,16,14,16,18,17,22,19,25,22,28,26,30,31,31,37,32,"
 	 "43,32,49,31,53,30,58,28,61,25,63,22,64,18,64,14,63,10,"
 	 "61,7,58,4,53,2,49,1,43,0,37,0,31,1,26,2,22,4,19,7,17,10,"
 	 "16,14;", fh);
-   if (fNewLines) putc('\n', fh);
+   if (fNewLines) PUTC('\n', fh);
 
    fputs("DL41,4,20,3,19,0,23,-4,24,-9,24,-14,23,-17,22,-20,19,"
 	 "-21,16,-20,13,-17,10,-14,9,-9,8,-4,8,0,9,3,11,4,12;", fh);
-   if (fNewLines) putc('\n', fh);
+   if (fNewLines) PUTC('\n', fh);
 #endif
 #if 0
    /* and set clipping (Input Window!) on plotter (left,bottom,right,top) */
@@ -117,7 +117,7 @@ HPGL::cross(const img_point *p, bool fSurface)
     /* clearly if this will work on older plotters (such as the HP9872)     */
     fprintf(fh, "PD;PR%d,%d;PR%d,%d;PU%d,0;PD%d,%d;PU%d,%d;PA;",
 	    CS, CS,  -CS2, -CS2,  CS2, /*0,*/  -CS2, CS2,  CS, -CS);
-    if (fNewLines) putc('\n', fh);
+    if (fNewLines) PUTC('\n', fh);
 }
 #undef CS
 #undef CS2
@@ -146,32 +146,32 @@ HPGL::label(const img_point *p, const char *s, bool fSurface)
 		/* (C) needs two chars to look right! */
 		/* This bit does the circle of the (C) symbol: */
 		fputs(HPGL_EOL";", fh);
-		if (fNewLines) putc('\n', fh);
+		if (fNewLines) PUTC('\n', fh);
 		fputs("UC2,3.5,99,0,1,0.125,1,0.25,.75,0.375,.75,"
 		      ".5,.5,.625,.25,.75,.25,.75,0,.75,-.25,.625,-.25,"
 		      ".5,-.5,.375,-.75,.25,-.75,.125,-1,0,-1,-0.125,-1,"
 		      "-0.25,-.75,-0.375,-.75,-.5,-.5,-.625,-.25,-.75,-.25,"
 		      "-.75,0,-.75,.25,-.625,.25,-.5,.5,-.375,.75,-.25,.75,"
 		      "-.125,1;", fh);
-		if (fNewLines) putc('\n', fh);
+		if (fNewLines) PUTC('\n', fh);
 		/* And this bit's the c in the middle: */
 		fputs("UC.5,5,99,-.125,.25,-.375,.5,-.5,.25,-.625,0,"
 		      "-.625,-.25,-.375,-.25,-.375,-.75,-.125,-.75,.125,-.75,"
 		      ".375,-.75,.375,-.25,.625,-.25,.625,0,.5,.25,.375,.5,"
 		      ".125,.25;", fh);
-		if (fNewLines) putc('\n', fh);
+		if (fNewLines) PUTC('\n', fh);
 		fputs("LB", fh);
 #else
 		fputs(HPGL_SO"(C)"HPGL_SI, fh);
 #endif
 		break;
 	    default:
-		putc(*s, fh);
+		PUTC(*s, fh);
 	}
 	s++;
     }
     fputs(HPGL_EOL";", fh);
-    if (fNewLines) putc('\n', fh);
+    if (fNewLines) PUTC('\n', fh);
 }
 
 void
@@ -179,5 +179,5 @@ HPGL::footer()
 {
    /* Clear clipping window;  New page.  NB PG is a no-op on the HP7475A */
    fputs("IW;PG;", fh);
-   if (fNewLines) putc('\n', fh);
+   if (fNewLines) PUTC('\n', fh);
 }
