@@ -173,14 +173,14 @@ unsigned int img_output_version = IMG_VERSION_MAX;
 #ifdef IMG_HOSTED
 static enum {
    IMG_NONE = 0,
-   IMG_FILENOTFOUND = /*Couldn't open data file `%s'*/24,
+   IMG_FILENOTFOUND = /*Couldn’t open data file “%s”*/24,
    IMG_OUTOFMEMORY  = /*Out of memory %.0s*/38,
-   IMG_DIRECTORY    = /*Filename `%s' refers to directory*/44,
-   IMG_CANTOPENOUT  = /*Failed to open output file `%s'*/47,
-   IMG_BADFORMAT    = /*Bad 3d image file `%s'*/106,
-   IMG_READERROR    = /*Error reading from file `%s'*/109,
-   IMG_WRITEERROR   = /*Error writing to file `%s'*/110,
-   IMG_TOONEW       = /*File `%s' has a newer format than this program can understand*/114
+   IMG_DIRECTORY    = /*Filename “%s” refers to directory*/44,
+   IMG_CANTOPENOUT  = /*Failed to open output file “%s”*/47,
+   IMG_BADFORMAT    = /*Bad 3d image file “%s”*/106,
+   IMG_READERROR    = /*Error reading from file “%s”*/109,
+   IMG_WRITEERROR   = /*Error writing to file “%s”*/110,
+   IMG_TOONEW       = /*File “%s” has a newer format than this program can understand*/114
 } img_errno = IMG_NONE;
 #else
 static img_errcode img_errno = IMG_NONE;
@@ -1821,7 +1821,7 @@ img_write_item(img *pimg, int code, int flags, const char *s,
 	 if (u < 0) u = -1;
 	 if (d < 0) d = -1;
 	 max_dim = max(max(l, r), max(u, d));
-	 flags &= 1;
+	 flags = (flags & img_XFLAG_END) ? 1 : 0;
 	 if (max_dim >= 32768) flags |= 2;
 	 write_v3label(pimg, 0x30 | flags, s);
 	 if (flags & 2) {
