@@ -33,6 +33,16 @@ MyLogWindow::MyLogWindow()
 {
 }
 
+#if wxCHECK_VERSION(2,9,0)
+void MyLogWindow::DoLogText(const wxChar *msg) {
+    if (first) {
+	wxLogWindow::DoLogText(wxString(GetGLSystemDescription().c_str(), wxConvUTF8));
+	first = false;
+    }
+    wxLogWindow::DoLogText(msg);
+    Show();
+}
+#else
 void MyLogWindow::DoLogString(const wxChar *msg, time_t timestamp) {
     if (first) {
 	wxLogWindow::DoLogString(wxString(GetGLSystemDescription().c_str(), wxConvUTF8), timestamp);
@@ -41,3 +51,4 @@ void MyLogWindow::DoLogString(const wxChar *msg, time_t timestamp) {
     wxLogWindow::DoLogString(msg, timestamp);
     Show();
 }
+#endif
