@@ -80,7 +80,7 @@ static const char *exe_pth = "";
 static void
 outofmem(OSSIZE_T size)
 {
-   fatalerror(/*Out of memory (couldn't find %lu bytes).*/1,
+   fatalerror(/*Out of memory (couldn’t find %lu bytes).*/1,
 	      (unsigned long)size);
 }
 
@@ -606,49 +606,49 @@ add_unicode(int charset, unsigned char *p, int value)
    }
    /* Transliterate characters we can't represent */
 #ifdef DEBUG
-   fprintf(stderr, "transliterate `%c' 0x%x\n", value, value);
+   fprintf(stderr, "transliterate “%c” 0x%x\n", value, value);
 #endif
    switch (value) {
     case 160:
       *p = ' '; return 1;
-    case 161 /*  */:
+    case 161 /* ¡ */:
       *p = '!'; return 1;
-    case 171 /*  */:
+    case 171 /* « */:
       p[1] = *p = '<'; return 2;
-    case 176 /*  */:
+    case 176 /* ° */:
       *p = 'd'; p[1] = 'g'; return 2;
-    case 187 /*  */:
+    case 187 /* » */:
       p[1] = *p = '>'; return 2;
-    case 191 /*  */:
+    case 191 /* ¿ */:
       *p = '?'; return 1;
-    case 192 /*  */: case 193 /*  */: case 194 /*  */: case 195 /*  */:
+    case 192 /* À */: case 193 /* Á */: case 194 /* Â */: case 195 /* Ã */:
       *p = 'A'; return 1;
-    case 197 /*  */:
+    case 197 /* Å */:
       p[1] = *p = 'A'; return 2;
-    case 196 /*  */: /* &Auml; */
+    case 196 /* Ä */: /* &Auml; */
       *p = 'A';
       if (!umlaut_to_e()) return 1;
       p[1] = 'E'; return 2;
-    case 198 /*  */:
+    case 198 /* Æ */:
       *p = 'A'; p[1] = 'E'; return 2;
-    case 199 /*  */: case 268: /* &Ccaron; */
+    case 199 /* Ç */: case 268: /* &Ccaron; */
       *p = 'C'; return 1;
     case 270: /* &Dcaron; */
       *p = 'D'; return 1;
-    case 200 /*  */: case 201 /*  */: case 202 /*  */: case 203 /*  */:
+    case 200 /* È */: case 201 /* É */: case 202 /* Ê */: case 203 /* Ë */:
       *p = 'E'; return 1;
-    case 204 /*  */: case 205 /*  */: case 206 /*  */: case 207 /*  */:
+    case 204 /* Ì */: case 205 /* Í */: case 206 /* Î */: case 207 /* Ï */:
       *p = 'I'; return 1;
-    case 208 /*  */: case 222 /*  */:
+    case 208 /* Ð */: case 222 /* Þ */:
       *p = 'T'; p[1] = 'H'; return 2;
     case 315: /* &Lacute; */
     case 317: /* &Lcaron; */
       *p = 'L'; return 1;
-    case 209 /*  */:
+    case 209 /* Ñ */:
       *p = 'N'; return 1;
-    case 210 /*  */: case 211 /*  */: case 212 /*  */: case 213 /*  */:
+    case 210 /* Ò */: case 211 /* Ó */: case 212 /* Ô */: case 213 /* Õ */:
       *p = 'O'; return 1;
-    case 214 /*  */: /* &Ouml; */ case 0x152: /* &OElig; */
+    case 214 /* Ö */: /* &Ouml; */ case 0x152: /* &OElig; */
       *p = 'O'; p[1] = 'E'; return 2;
     case 352: /* &Scaron; */
     case 0x15e: /* &Scedil; */
@@ -656,36 +656,36 @@ add_unicode(int charset, unsigned char *p, int value)
     case 0x162: /* &Tcedil; */
     case 0x164: /* &Tcaron; */
       *p = 'T'; return 1;
-    case 217 /*  */: case 218 /*  */: case 219 /*  */:
+    case 217 /* Ù */: case 218 /* Ú */: case 219 /* Û */:
       *p = 'U'; return 1;
-    case 220 /*  */: /* &Uuml; */
+    case 220 /* Ü */: /* &Uuml; */
       *p = 'U'; p[1] = 'E'; return 2;
-    case 221 /*  */:
+    case 221 /* Ý */:
       *p = 'Y'; return 1;
     case 381: /* &Zcaron; */
       *p = 'Z'; return 1;
-    case 223 /*  */:
+    case 223 /* ß */:
       p[1] = *p = 's'; return 2;
-    case 224 /*  */: case 225 /*  */: case 226 /*  */: case 227 /*  */:
+    case 224 /* à */: case 225 /* á */: case 226 /* â */: case 227 /* ã */:
     case 259: /* &abreve; */
       *p = 'a'; return 1;
-    case 228 /*  */: /* &auml; */ case 230 /*  */:
+    case 228 /* ä */: /* &auml; */ case 230 /* æ */:
       *p = 'a'; p[1] = 'e'; return 2;
-    case 229 /*  */:
+    case 229 /* å */:
       p[1] = *p = 'a'; return 2;
-    case 231 /*  */: case 269 /* &ccaron; */:
+    case 231 /* ç */: case 269 /* &ccaron; */:
       *p = 'c'; return 1;
     case 271: /* &dcaron; */
       *p = 'd'; return 1;
-    case 232 /*  */: case 233 /*  */: case 234 /*  */: case 235 /*  */:
+    case 232 /* è */: case 233 /* é */: case 234 /* ê */: case 235 /* ë */:
     case 283 /* &ecaron; */:
       *p = 'e'; return 1;
-    case 236 /*  */: case 237 /*  */: case 238 /*  */: case 239 /*  */:
+    case 236 /* ì */: case 237 /* í */: case 238 /* î */: case 239 /* ï */:
       *p = 'i'; return 1;
     case 316 /* &lacute; */:
     case 318 /* &lcaron; */:
       *p = 'l'; return 1;
-    case 241 /*  */: case 328 /* &ncaron; */:
+    case 241 /* ñ */: case 328 /* &ncaron; */:
       *p = 'n'; return 1;
     case 345: /* &rcaron; */
       *p = 'r'; return 1;
@@ -695,21 +695,25 @@ add_unicode(int charset, unsigned char *p, int value)
     case 357: /* &tcaron; */
     case 0x163: /* &tcedil; */
       *p = 't'; return 1;
-    case 240 /*  */: case 254 /*  */:
+    case 240 /* ð */: case 254 /* þ */:
       *p = 't'; p[1] = 'h'; return 2;
-    case 242 /*  */: case 243 /*  */: case 244 /*  */: case 245 /*  */:
+    case 242 /* ò */: case 243 /* ó */: case 244 /* ô */: case 245 /* õ */:
       *p = 'o'; return 1;
-    case 246 /*  */: /* &ouml; */ case 0x153: /* &oelig; */
+    case 246 /* ö */: /* &ouml; */ case 0x153: /* &oelig; */
       *p = 'o'; p[1] = 'e'; return 2;
-    case 249 /*  */: case 250 /*  */: case 251 /*  */:
+    case 249 /* ù */: case 250 /* ú */: case 251 /* û */:
     case 367 /* &uring; */:
       *p = 'u'; return 1;
-    case 252 /*  */: /* &uuml; */
+    case 252 /* ü */: /* &uuml; */
       *p = 'u'; p[1] = 'e'; return 2;
-    case 253 /*  */: case 255 /*  */:
+    case 253 /* ý */: case 255 /* ÿ */:
       *p = 'y'; return 1;
     case 382: /* &zcaron; */
       *p = 'z'; return 1;
+    case 0x2019: /* &lsquo; */
+      *p = '\''; return 1;
+    case 0x201c: /* &ldquo; */ case 0x201d: /* &rdquo; */
+      *p = '"'; return 1;
     case 0x2026: /* &hellip; */
       *p = '.'; p[1] = '.'; p[2] = '.'; return 3;
     case 0x2192: /* &rarr; */
@@ -782,8 +786,8 @@ parse_msgs(int n, unsigned char *p, int charset_code) {
 	    *to++ = (char)ch;
 	 } else {
 	    /* We assume an N byte UTF-8 code never transliterates to more
-	     * than N characters (so we can't transliterate  to (C) or
-	     *  to (R) for example) */
+	     * than N characters (so we can't transliterate © to (C) or
+	     * ® to (R) for example) */
 	    to += add_unicode(charset_code, to, ch);
 	 }
       }
@@ -801,8 +805,8 @@ parse_msgs(int n, unsigned char *p, int charset_code) {
 #else
 #define N_DONTEXTRACTMSGS 5
 static unsigned char dontextractmsgs[] =
-   "Can't open message file `%s' using path `%s'\0"/*1000*/
-   "Problem with message file `%s'\0"/*1001*/
+   "Can't open message file “%s” using path “%s”\0"/*1000*/
+   "Problem with message file “%s”\0"/*1001*/
    "I don't understand this message file version\0"/*1002*/
    "Message file truncated?\0"/*1003*/
    "Out of memory (couldn't find %lu bytes).\0"/*1004*/;
@@ -845,13 +849,13 @@ parse_msg_file(int charset_code)
    }
 
    if (!fh) {
-      fatalerror(/*Can't open message file `%s' using path `%s'*/1000,
+      fatalerror(/*Can't open message file “%s” using path “%s”*/1000,
 		 fnm, pth_cfg_files);
    }
 
    if (fread(header, 1, 20, fh) < 20 ||
        memcmp(header, "Svx\nMsg\r\n\xfe\xff", 12) != 0) {
-      fatalerror(/*Problem with message file `%s'*/1001, fnm);
+      fatalerror(/*Problem with message file “%s”*/1001, fnm);
    }
 
    if (header[12] != 0)
@@ -869,7 +873,7 @@ parse_msg_file(int charset_code)
    fclose(fh);
 
 #ifdef DEBUG
-   fprintf(stderr, "fnm = `%s', n = %d, len = %d\n", fnm, n, len);
+   fprintf(stderr, "fnm = “%s”, n = %d, len = %d\n", fnm, n, len);
 #endif
    osfree(fnm);
 
@@ -901,9 +905,6 @@ msg_init(char * const *argv)
    char *p;
    SVX_ASSERT(argv);
 
-#ifdef HAVE_SIGNAL
-   init_signals();
-#endif
    /* Point to argv[0] itself so we report a more helpful error if the
     * code to work out the clean appname generates a signal */
    appname_copy = argv[0];
@@ -1120,6 +1121,12 @@ macosx_got_msg:
 #endif
 
    select_charset(def_charset);
+
+#ifdef HAVE_SIGNAL
+   /* Initialise signal handlers only after the messages have been as we need
+    * the messages to usefully handle the signals. */
+   init_signals();
+#endif
 }
 
 /* Message may be overwritten by next call
@@ -1129,12 +1136,11 @@ msg(int en)
 {
    /* NB can't use SVX_ASSERT here! */
    static char badbuf[256];
-   if (en >= 1000 && en < 1000 + N_DONTEXTRACTMSGS)
+   if (dontextract && en >= 1000 && en < 1000 + N_DONTEXTRACTMSGS)
       return dontextract[en - 1000];
    if (!msg_array) {
       if (en != 1)  {
-	 sprintf(badbuf, "Message %d requested before msg_array initialised\n",
-		 en);
+	 sprintf(badbuf, "Message %d requested before fully initialised\n", en);
 	 return badbuf;
       }
       /* this should be the only other message which can be requested before
